Tutorial
========

* TODO: Build an example repo that uses Pemi and has a full job
* TODO: Build a full integration job based off of the CSV job
* TODO: Guide for writing your own data subjects
* TODO: Guide for writing custom test conditions
* TODO: Row-focused tests vs column-focused tests
* TODO: Managing schemas as data flows through multiple pipes
